=============
Django-Twilio
=============

Integrate Twilio into your Django apps with ease.


.. image:: https://badge.fury.io/py/django-twilio.png
    :target: http://badge.fury.io/py/django-twilio

.. image:: https://travis-ci.org/rdegges/django-twilio.png?branch=master
        :target: https://travis-ci.org/rdegges/django-twilio

.. image:: https://pypip.in/d/django-twilio/badge.png
        :target: https://crate.io/packages/django-twilio

Meta
----

* Author: Randall Degges
* Email:  rdegges@gmail.com
* Maintainer: Paul Hallett
* Email: paul@twilio.com
* Status: active development, stable, maintained

`Twilio <http://www.twilio.com/>`_ is a powerful HTTP API that allows you to
build powerful voice & SMS apps. The goal of this library is to help make
building telephony applications as simple as humanly possible with twilio.


User's Guide
------------

This part of the documentation contains an extensive walk through of
django-twilio. It begins with some background information about django-twilio,
then focuses on step-by-step integration of django-twilio into your existing
Django web applications.

.. toctree::
    :maxdepth: 2

    foreword
    install
    decorators
    views
    rest
    gotchas
    howto
    contribute


Indices and Tables
------------------

The following is auto-generated documentation that can be used to quickly find
relevant parts of this documentation.

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
